<?php
/**
 * ShopEx licence
 *
 * @copyright  Copyright (c) 2005-2010 ShopEx Technologies Inc. (http://www.shopex.cn)
 * @license  http://ecos.shopex.cn/ ShopEx License
 */

// http://localhost/bbc/public/index.php/utils/apiCheck.html?api=trade.order.list.get
class toputil_ctl_apiCheck {

    public $doc_title = "ONEX B2B2C 商城API参数查询";

    public function __construct()
    {
        if (!config::get('app.debug'))
        {
            return kernel::abort(404);
        }
    }

    public function getApiDoc(){
        $apiKey = input::get('api');
        $apis = config::get('apis.routes');

        foreach ($apis as $key => &$value)
        {
            list($class, $method) = explode('@', $value['uses']);
            $rfc = new ReflectionClass($class);
            $value['apiDesc'] = $rfc->getDefaultProperties()['apiDescription'];
        }

        $doc['apis'] = $apis;
        foreach( $apis as $key=>$row )
        {
            $handle = $row['uses'];
            list($class, $method) = explode('@', $handle);
            $handlar = new $class;
            $apigroup = $this->__getTitle2($handle);
            $doc['list'][$apigroup][$key] = $row;
            $doc['count'][$apigroup] += 1;
        }

        if($apiKey && $apis[$apiKey])
        {
            $api_conf = $apis[$apiKey];
            $handle = $api_conf['uses'];
            list($class, $method) = explode('@', $handle);
            $handlar = new $class;
            $doc['apiKey'] = $apiKey;
            $doc['apidesc'] = $this->__getTitle1($handlar);
            $doc['apigroup'] = $this->__getTitle2($handle);
            $doc['system_params'] = $this->__getSystemParams();
            $doc['params'] = $this->__getParams($handlar);
            $doc['response'] = $this->__getResponse($class, $method);
            return view::make('toputil/apiCheck/apiCheck.html', $doc);
        }
        else
        {
            if( input::get('group') && $doc['list'][input::get('group')] )
            {
                $doc['activeGroup']['apiList'] = $doc['list'][input::get('group')];
                $doc['activeGroup']['name'] = input::get('group');
            }
            else
            {
                $doc['activeGroup']['apiList'] = current($doc['list']);
                $doc['activeGroup']['name'] = key($doc['list']);
            }

            return view::make('toputil/apiCheck/list.html', $doc);
        }

    }

    private function __getTitle2($handle)
    {
        $args = explode('_', $handle);
        $app_name = $args[0];
        $app_titles = config::get('prism.prismApiName', array());
        $app_title = $app_titles[$app_name] ? $app_titles[$app_name] . '相关API' : $app_name;

        return $app_title;
    }

    private function __getTitle1($api_handlar)
    {
        return $api_handlar->apiDescription;
    }

    private function __getSystemParams()
    {
        return [
            [
                'field' => 'method',
                'title' => 'API的方法名',
                'type' => 'string',
                'validate' => 'required',
                'example' => 'trade.get',
                'desc' => '标识请求的是哪个API',
            ],
            [
                'field' => 'format',
                'title' => '返回数据格式',
                'type' => 'string',
                'validate' => 'required',
                'example' => 'json',
                'desc' => '返回数据是json格式的，目前只支持json',
            ],
            [
                'field' => 'v',
                'title' => '版本号',
                'type' => 'string',
                'validate' => 'required',
                'example' => 'v1',
                'desc' => '标识该接口的版本',
            ],
        ];
    }

    private function __getParams($handlar)
    {
        $return = $handlar->getParams();
        $params = $return['params'];
        $ret = array();
        foreach($params as $key=>$value)
        {
            $field = array();
            $field['field'] = $key;
            $field['title'] = $value['title']?:$value['description'];
            $field['type'] = $value['type'];
            $field['validate'] = $value['valid'];
            $field['example'] = $value['example'];
            $field['desc'] = $value['desc']?:$value['description'];
            $ret[] = $field;
        }
        return $ret;
    }

    private function __getResponse($class, $method)
    {
        $rMethod = new ReflectionMethod($class, $method);

        $docComment = $rMethod->getDocComment();
        $docCommentArr = explode("\n", $docComment);

        foreach ($docCommentArr as $comment)
        {
            $comment = trim($comment);

            //标题描述
            if (empty($description) && strpos($comment, '@') === false && strpos($comment, '/') === false)
            {
                $description = substr($comment, strpos($comment, '*') + 1);
                continue;
            }

            //@desc注释
            $pos = stripos($comment, '@desc');
            if ($pos !== false)
            {
                $descComment = substr($comment, $pos + 5);
                continue;
            }

            //@return注释
            $pos = stripos($comment, '@return');
            if ($pos === false)
            {
                continue;
            }

            $returnCommentArr = explode(' ', substr($comment, $pos + 8));
            if (count($returnCommentArr) < 2)
            {
                continue;
            }
            if (!isset($returnCommentArr[2]))
            {
                $returnCommentArr[2] = '';  //可选的字段说明
            }
            else
            {
                //兼容处理有空格的注释
                $returnCommentArr[2] = implode(' ', array_slice($returnCommentArr, 2));
            }

            $returns[] = $returnCommentArr;
        }
        return $returns;
    }

}
